@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 
 # isbnlib - tools for extracting, cleaning and transforming ISBNs
-# Copyright (C) 2014-2018 Alexandre Lima Conde
+# Copyright (C) 2014-2020 Alexandre Lima Conde
+# SPDX-License-Identifier: LGPL-3.0-or-later
 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,7 +16,7 @@
 
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
-"""isbnlib main file.
+"""isbnlib main file for ISBN manipulation.
 
 Tools for extracting, cleaning, transforming and validating ISBN ids.
 """
@@ -28,20 +29,24 @@ LOGGER = logging.getLogger(__name__)
 RE_ISBN10 = re.compile(r'ISBN\x20(?=.{13}$)\d{1,5}([- ])\d{1,7}'
                        r'\1\d{1,6}\1(\d|X)$|[- 0-9X]{10,16}')
 RE_ISBN13 = re.compile(r'97[89]{1}(?:-?\d){10,16}|97[89]{1}[- 0-9]{10,16}')
-RE_STRICT = re.compile(r'^(?:ISBN(?:-1[03])?:? )?(?=[0-9X]{10}$|'
-                       r'(?=(?:[0-9]+[- ]){3})'
-                       r'[- 0-9X]{13}$|97[89][0-9]{10}$|'
-                       r'(?=(?:[0-9]+[- ]){4})'
-                       r'[- 0-9]{17}$)(?:97[89][- ]?)?[0-9]{1,5}'
-                       r'[- ]?[0-9]+[- ]?[0-9]+[- ]?[0-9X]$',
-                       re.I | re.M | re.S)
-RE_NORMAL = re.compile(r'97[89]{1}(?:-?\d){10}|\d{9}[0-9X]{1}|'
-                       r'[-0-9X]{10,16}', re.I | re.M | re.S)
+RE_STRICT = re.compile(
+    r'^(?:ISBN(?:-1[03])?:? )?(?=[0-9X]{10}$|'
+    r'(?=(?:[0-9]+[- ]){3})'
+    r'[- 0-9X]{13}$|97[89][0-9]{10}$|'
+    r'(?=(?:[0-9]+[- ]){4})'
+    r'[- 0-9]{17}$)(?:97[89][- ]?)?[0-9]{1,5}'
+    r'[- ]?[0-9]+[- ]?[0-9]+[- ]?[0-9X]$',
+    re.I | re.M | re.S,
+)
+RE_NORMAL = re.compile(
+    r'97[89]{1}(?:-?\d){10}|\d{9}[0-9X]{1}|'
+    r'[-0-9X]{10,16}', re.I | re.M | re.S)
 RE_LOOSE = re.compile(r'[- 0-9X]{10,19}', re.I | re.M | re.S)
 ISBN13_PREFIX = '978'
 LEGAL = '0123456789xXisbnISBN- '
 
 
+# pylint: disable=broad-except
 def check_digit10(firstninedigits):
     """Check sum ISBN-10."""
     # minimum checks
@@ -64,6 +69,7 @@ def check_digit10(firstninedigits):
     return str(tenthdigit)
 
 
+# pylint: disable=broad-except
 def check_digit13(firsttwelvedigits):
     """Check sum ISBN-13."""
     # minimum checks
@@ -82,23 +88,26 @@ def check_digit13(firsttwelvedigits):
     return str(thirteenthdigit)
 
 
+# pylint: disable=simplifiable-if-expression
 def _check_structure10(isbn10like):
     """Check structure of an ISBN-10."""
-    return True if re.match(RE_ISBN10, isbn10like) else False
+    return bool(re.match(RE_ISBN10, isbn10like))
 
 
+# pylint: disable=simplifiable-if-expression
 def _check_structure13(isbn13like):
     """Check structure of an ISBN-13."""
-    return True if re.match(RE_ISBN13, isbn13like) else False
+    return bool(re.match(RE_ISBN13, isbn13like))
 
 
+# pylint: disable=simplifiable-if-expression
 def is_isbn10(isbn10):
     """Validate as ISBN-10."""
     isbn10 = canonical(isbn10)
     if len(isbn10) != 10:
         return False  # pragma: no cover
     else:
-        return False if check_digit10(isbn10[:-1]) != isbn10[-1] else True
+        return bool(not check_digit10(isbn10[:-1]) != isbn10[-1])
 
 
 def is_isbn13(isbn13):
@@ -109,7 +118,7 @@ def is_isbn13(isbn13):
     else:
         if isbn13[0:3] not in ('978', '979'):
             return False
-        return False if check_digit13(isbn13[:-1]) != isbn13[-1] else True
+        return bool(not check_digit13(isbn13[:-1]) != isbn13[-1])
 
 
 def to_isbn10(isbn13):
@@ -143,7 +152,13 @@ def canonical(isbnlike):
     numb = [c for c in isbnlike if c in '0123456789Xx']
     if numb and numb[-1] == 'x':
         numb[-1] = 'X'
-    return ''.join(numb)
+    isbn = ''.join(numb)
+    # Filter some special cases
+    if (isbn and len(isbn) not in (10, 13)
+            or isbn in ('0000000000', '0000000000000', '000000000X')
+            or isbn.find('X') not in (9, -1) or isbn.find('x') != -1):
+        return ''
+    return isbn
 
 
 def clean(isbnlike):
@@ -185,6 +200,7 @@ def get_isbnlike(text, level='normal'):
 
     """
     if level == 'normal':  # pragma: no cover
+        text = text.replace('-97', '- 97')
         isbnlike = RE_NORMAL
     elif level == 'strict':
         isbnlike = RE_STRICT
@@ -213,8 +229,9 @@ def get_canonical_isbn(isbnlike, output='bouth'):
 
     match = regex.search(isbnlike)
     if match:
-        # Get only canonical characters and split them into a list
+        # Get only canonical characters
         cisbn = canonical(match.group())
+        # Split into a list
         chars = list(cisbn)
         # Remove the last digit from `chars` and assign it to `last`
         last = chars.pop()
