@@ -4,23 +4,20 @@
 import logging
 
 from ._core import get_canonical_isbn, get_isbnlike
-from .dev import webservice
+from .dev import cache, webservice
 
 try:  # pragma: no cover
     from urllib.parse import quote
 except ImportError:  # pragma: no cover
-
-    def quote(x):  # pragma: no cover
-        """Do nothing if PY2."""
-        return x
-
+    from urllib import quote
 
 LOGGER = logging.getLogger(__name__)
 
 
+@cache
 def goos(words):
     """Use Google to get an ISBN from words from title and author's name."""
-    service_url = "http://www.google.com/search?q=ISBN+"
+    service_url = 'http://www.google.com/search?q=ISBN+'
     search_url = service_url + quote(words.replace(' ', '+'))
 
     user_agent = 'w3m/0.5.3'
@@ -31,14 +28,14 @@ def goos(words):
         appheaders={
             'Content-Type': 'text/plain; charset="UTF-8"',
             'Content-Transfer-Encoding': 'Quoted-Printable',
-        })
+        },
+    )
     isbns = get_isbnlike(content)
 
     for item in isbns:
         isbn = get_canonical_isbn(item, output='isbn13')
-        if isbn:
+        if isbn:  # pragma: no cover
             break
     if not isbns or not isbn:  # pragma: no cover
         LOGGER.debug('No ISBN found for %s', words)
-        return None
-    return isbn
+    return isbn if isbn else None
