@@ -24,7 +24,7 @@ endnote = r"""%0 Book
 %D $Year
 %I $Publisher """
 
-refworks = r"""TY  - BOOK
+ris = r"""TY  - BOOK
 T1  - $Title
 A1  - $AUTHORS
 SN  - $ISBN
@@ -32,8 +32,8 @@ Y1  - $Year
 PB  - $Publisher
 ER  - """
 
-msword = r'''<b:Source xmlns:b="http://schemas.microsoft.com/office/'''\
-         r'''word/2004/10/bibliography">
+msword = (r"""<b:Source xmlns:b="http://schemas.microsoft.com/office/"""
+          r"""word/2004/10/bibliography">
 <b:Tag>$uid</b:Tag>
 <b:SourceType>Book</b:SourceType>
 <b:Author>
@@ -44,22 +44,22 @@ msword = r'''<b:Source xmlns:b="http://schemas.microsoft.com/office/'''\
 <b:Year>$Year</b:Year>
 <b:City></b:City>
 <b:Publisher>$Publisher</b:Publisher>
-</b:Source>'''
+</b:Source>""")
 
-json = r'''{"type": "book",
+json = r"""{"type": "book",
      "title": "$Title",
     "author": [$AUTHORS],
       "year": "$Year",
 "identifier": [{"type": "ISBN", "id": "$ISBN"}],
- "publisher": "$Publisher"}'''
+ "publisher": "$Publisher"}"""
 
-csl = r'''{"type":"book",
+csl = r"""{"type":"book",
         "id":"$ISBN",
      "title":"$Title",
     "author": [$AUTHORS],
-    "issued": {"date_parts": [[$Year]]},
+    "issued": {"date-parts": [[$Year]]},
       "ISBN":"$ISBN",
- "publisher":"$Publisher"}'''
+ "publisher":"$Publisher"}"""
 
 opf = r"""<?xml version='1.0' encoding='utf-8'?>
 <package version="2.0" xmlns="http://www.idpf.org/2007/opf" unique-identifier="uuid_id">
@@ -86,11 +86,11 @@ templates = {
     'labels': labels,
     'bibtex': bibtex,
     'endnote': endnote,
-    'refworks': refworks,
+    'ris': ris,
     'msword': msword,
     'json': json,
     'csl': csl,
-    'opf': opf
+    'opf': opf,
 }
 
 _fmts = list(templates.keys())
@@ -107,29 +107,31 @@ def _spec_proc(name, fmtrec, authors):
     """Fix the Authors records."""
     if name not in _fmts:
         return
+    if not authors:
+        return
     if name == 'labels':
         AUTHORS = '\nAuthor:    '.join(authors)
     elif name == 'bibtex':
         AUTHORS = ' and '.join(authors)
-    elif name == 'refworks':
+    elif name == 'ris':
         AUTHORS = '\nA1  - '.join(authors)
     elif name == 'endnote':
         AUTHORS = '\n%A '.join(authors)
     elif name == 'msword':
         fmtrec = fmtrec.replace('$uid', str(uuid.uuid4()))
-        person = r"<b:Person><b:Last>$last</b:Last>"\
-                 r"<b:First>$first</b:First></b:Person>"
+        person = (r'<b:Person><b:Last>$last</b:Last>'
+                  r'<b:First>$first</b:First></b:Person>')
         AUTHORS = '\n'.join(
             Template(person).safe_substitute(last_first(a)) for a in authors)
     elif name == 'json':
-        AUTHORS = ', '.join('{"name": "$"}'.replace("$", a) for a in authors)
+        AUTHORS = ', '.join('{"name": "$"}'.replace('$', a) for a in authors)
     elif name == 'csl':
-        AUTHORS = ', '.join(
-            '{"literal": "$"}'.replace("$", a) for a in authors)
+        AUTHORS = ', '.join('{"literal": "$"}'.replace('$', a)
+                            for a in authors)
     elif name == 'opf':
         fmtrec = fmtrec.replace('$uid', str(uuid.uuid4()))
-        creator = r'<dc:creator opf:file-as="$last, $first"'\
-                  r' opf:role="aut">$first $last</dc:creator>'
+        creator = (r'<dc:creator opf:file-as="$last, $first"'
+                   r' opf:role="aut">$first $last</dc:creator>')
         AUTHORS = '\n    '.join(
             Template(creator).safe_substitute(last_first(author))
             for author in authors)
@@ -139,4 +141,4 @@ def _spec_proc(name, fmtrec, authors):
 def _fmtbib(fmtname, canonical):
     """Return a canonical record in the selected format."""
     return _spec_proc(fmtname, _gen_proc(fmtname, canonical),
-                      canonical['Authors'])
+                      canonical.get('Authors'))
