@@ -6,7 +6,7 @@ import logging
 
 from ._bouth23 import bstream, s
 from ._exceptions import ISBNLibHTTPError, ISBNLibURLError
-from .. import config
+from ..config import options
 
 # pylint: disable=import-error
 # pylint: disable=wrong-import-order
@@ -24,11 +24,13 @@ LOGGER = logging.getLogger(__name__)
 
 
 # pylint: disable=too-few-public-methods
+# pylint: disable=useless-object-inheritance
 class WEBService(object):
     """Class to query web services."""
 
     def __init__(self, url, user_agent=UA, values=None, appheaders=None):
         """Initialize main properties."""
+        # TODO(use urllib.quote to the non-ascii part?)
         self._url = url
         # headers to accept gzipped content
         headers = {'Accept-Encoding': 'gzip', 'User-Agent': user_agent}
@@ -42,17 +44,18 @@ class WEBService(object):
     def response(self):
         """Check errors on response."""
         try:
-            response = urlopen(self._request, timeout=config.URLOPEN_TIMEOUT)
+            response = urlopen(self._request,
+                               timeout=options.get('URLOPEN_TIMEOUT'))
             LOGGER.debug('Request headers:\n%s', self._request.header_items())
         except HTTPError as e:  # pragma: no cover
             LOGGER.critical('ISBNLibHTTPError for %s with code %s [%s]',
                             self._url, e.code, e.msg)
             if e.code in (401, 403, 429):
-                raise ISBNLibHTTPError(
-                    '%s Are you making many requests?' % e.code)
+                raise ISBNLibHTTPError('%s Are you making many requests?' %
+                                       e.code)
             if e.code in (502, 504):
-                raise ISBNLibHTTPError(
-                    '%s Service temporarily unavailable!' % e.code)
+                raise ISBNLibHTTPError('%s Service temporarily unavailable!' %
+                                       e.code)
             raise ISBNLibHTTPError('(%s) %s' % (e.code, e.msg))
         except URLError as e:  # pragma: no cover
             LOGGER.critical('ISBNLibURLError for %s with reason %s', self._url,
@@ -75,8 +78,10 @@ class WEBService(object):
 
 def query(url, user_agent=UA, values=None, appheaders=None):
     """Query to a web service."""
-    service = WEBService(
-        url, user_agent=user_agent, values=values, appheaders=appheaders)
+    service = WEBService(url,
+                         user_agent=user_agent,
+                         values=values,
+                         appheaders=appheaders)
     data = service.data()
     LOGGER.debug('Raw data from service:\n%s', data)
     return data
